==> kubernetes-model-networking-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/HTTPIngressPathFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class HTTPIngressPathFluentImpl<A extends HTTPIngressPathFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements HTTPIngressPathFluent<A> {

    private IngressBackendBuilder backend;
    private String path;
    private String pathType;

    public HTTPIngressPathFluentImpl() {
    }

    public HTTPIngressPathFluentImpl(HTTPIngressPath instance) {
        this.withBackend(instance.getBackend()); 
        this.withPath(instance.getPath()); 
        this.withPathType(instance.getPathType()); 
    }

    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public IngressBackend getBackend() {
        return this.backend!=null?this.backend.build():null;
    }

    public IngressBackend buildBackend() {
        return this.backend!=null?this.backend.build():null;
    }

    public A withBackend(IngressBackend backend) {
        _visitables.get("backend").remove(this.backend);
        if (backend!=null){ this.backend= new IngressBackendBuilder(backend); _visitables.get("backend").add(this.backend);} return (A) this;
    }

    public Boolean hasBackend() {
        return this.backend != null;
    }

    public HTTPIngressPathFluent.BackendNested<A> withNewBackend() {
        return new BackendNestedImpl();
    }

    public HTTPIngressPathFluent.BackendNested<A> withNewBackendLike(IngressBackend item) {
        return new BackendNestedImpl(item);
    }

    public HTTPIngressPathFluent.BackendNested<A> editBackend() {
        return withNewBackendLike(getBackend());
    }

    public HTTPIngressPathFluent.BackendNested<A> editOrNewBackend() {
        return withNewBackendLike(getBackend() != null ? getBackend(): new IngressBackendBuilder().build());
    }

    public HTTPIngressPathFluent.BackendNested<A> editOrNewBackendLike(IngressBackend item) {
        return withNewBackendLike(getBackend() != null ? getBackend(): item);
    }

    public String getPath() {
        return this.path;
    }

    public A withPath(String path) {
        this.path=path; return (A) this;
    }

    public Boolean hasPath() {
        return this.path != null;
    }

    public A withNewPath(StringBuilder arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(int[] arg1,int arg2,int arg3) {
        return (A)withPath(new String(arg1, arg2, arg3));
    }

    public A withNewPath(char[] arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuffer arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(byte[] arg1,int arg2) {
        return (A)withPath(new String(arg1, arg2));
    }

    public A withNewPath(byte[] arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(char[] arg1,int arg2,int arg3) {
        return (A)withPath(new String(arg1, arg2, arg3));
    }

    public A withNewPath(byte[] arg1,int arg2,int arg3) {
        return (A)withPath(new String(arg1, arg2, arg3));
    }

    public A withNewPath(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withPath(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewPath(String arg1) {
        return (A)withPath(new String(arg1));
    }

    public String getPathType() {
        return this.pathType;
    }

    public A withPathType(String pathType) {
        this.pathType=pathType; return (A) this;
    }

    public Boolean hasPathType() {
        return this.pathType != null;
    }

    public A withNewPathType(StringBuilder arg1) {
        return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(int[] arg1,int arg2,int arg3) {
        return (A)withPathType(new String(arg1, arg2, arg3));
    }

    public A withNewPathType(char[] arg1) {
        return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(StringBuffer arg1) {
        return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(byte[] arg1,int arg2) {
        return (A)withPathType(new String(arg1, arg2));
    }

    public A withNewPathType(byte[] arg1) {
        return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(char[] arg1,int arg2,int arg3) {
        return (A)withPathType(new String(arg1, arg2, arg3));
    }

    public A withNewPathType(byte[] arg1,int arg2,int arg3) {
        return (A)withPathType(new String(arg1, arg2, arg3));
    }

    public A withNewPathType(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withPathType(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewPathType(String arg1) {
        return (A)withPathType(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        HTTPIngressPathFluentImpl that = (HTTPIngressPathFluentImpl) o;
        if (backend != null ? !backend.equals(that.backend) :that.backend != null) return false;
        if (path != null ? !path.equals(that.path) :that.path != null) return false;
        if (pathType != null ? !pathType.equals(that.pathType) :that.pathType != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(backend,  path,  pathType,  super.hashCode());
    }

    public class BackendNestedImpl<N> extends IngressBackendFluentImpl<HTTPIngressPathFluent.BackendNested<N>> implements HTTPIngressPathFluent.BackendNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final IngressBackendBuilder builder;

            BackendNestedImpl(IngressBackend item) {
                this.builder = new IngressBackendBuilder(this, item);
                        
            }

            BackendNestedImpl() {
                this.builder = new IngressBackendBuilder(this);
                        
            }

            public N and() {
                return (N) HTTPIngressPathFluentImpl.this.withBackend(builder.build());
            }

            public N endBackend() {
                return and();
            }
    }


}

==> kubernetes-model-networking-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/HTTPIngressPathFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class HTTPIngressPathFluentImpl<A extends HTTPIngressPathFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements HTTPIngressPathFluent<A> {

    private IngressBackendBuilder backend;
    private String path;
    private String pathType;

    public HTTPIngressPathFluentImpl() {
    }

    public HTTPIngressPathFluentImpl(HTTPIngressPath instance) {
        this.withBackend(instance.getBackend()); 
        this.withPath(instance.getPath()); 
        this.withPathType(instance.getPathType()); 
    }

    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public IngressBackend getBackend() {
        return this.backend!=null?this.backend.build():null;
    }

    public IngressBackend buildBackend() {
        return this.backend!=null?this.backend.build():null;
    }

    public A withBackend(IngressBackend backend) {
        _visitables.get("backend").remove(this.backend);
        if (backend!=null){ this.backend= new IngressBackendBuilder(backend); _visitables.get("backend").add(this.backend);} return (A) this;
    }

    public Boolean hasBackend() {
        return this.backend != null;
    }

    public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathFluent.BackendNested<A> withNewBackend() {
        return new BackendNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathFluent.BackendNested<A> withNewBackendLike(IngressBackend item) {
        return new BackendNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathFluent.BackendNested<A> editBackend() {
        return withNewBackendLike(getBackend());
    }

    public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathFluent.BackendNested<A> editOrNewBackend() {
        return withNewBackendLike(getBackend() != null ? getBackend(): new IngressBackendBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathFluent.BackendNested<A> editOrNewBackendLike(IngressBackend item) {
        return withNewBackendLike(getBackend() != null ? getBackend(): item);
    }

    public String getPath() {
        return this.path;
    }

    public A withPath(String path) {
        this.path=path; return (A) this;
    }

    public Boolean hasPath() {
        return this.path != null;
    }

    public A withNewPath(StringBuilder arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(int[] arg1,int arg2,int arg3) {
        return (A)withPath(new String(arg1, arg2, arg3));
    }

    public A withNewPath(char[] arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuffer arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(byte[] arg1,int arg2) {
        return (A)withPath(new String(arg1, arg2));
    }

    public A withNewPath(byte[] arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(char[] arg1,int arg2,int arg3) {
        return (A)withPath(new String(arg1, arg2, arg3));
    }

    public A withNewPath(byte[] arg1,int arg2,int arg3) {
        return (A)withPath(new String(arg1, arg2, arg3));
    }

    public A withNewPath(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withPath(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewPath(String arg1) {
        return (A)withPath(new String(arg1));
    }

    public String getPathType() {
        return this.pathType;
    }

    public A withPathType(String pathType) {
        this.pathType=pathType; return (A) this;
    }

    public Boolean hasPathType() {
        return this.pathType != null;
    }

    public A withNewPathType(StringBuilder arg1) {
        return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(int[] arg1,int arg2,int arg3) {
        return (A)withPathType(new String(arg1, arg2, arg3));
    }

    public A withNewPathType(char[] arg1) {
        return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(StringBuffer arg1) {
        return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(byte[] arg1,int arg2) {
        return (A)withPathType(new String(arg1, arg2));
    }

    public A withNewPathType(byte[] arg1) {
        return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(char[] arg1,int arg2,int arg3) {
        return (A)withPathType(new String(arg1, arg2, arg3));
    }

    public A withNewPathType(byte[] arg1,int arg2,int arg3) {
        return (A)withPathType(new String(arg1, arg2, arg3));
    }

    public A withNewPathType(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withPathType(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewPathType(String arg1) {
        return (A)withPathType(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        HTTPIngressPathFluentImpl that = (HTTPIngressPathFluentImpl) o;
        if (backend != null ? !backend.equals(that.backend) :that.backend != null) return false;
        if (path != null ? !path.equals(that.path) :that.path != null) return false;
        if (pathType != null ? !pathType.equals(that.pathType) :that.pathType != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(backend,  path,  pathType,  super.hashCode());
    }

    public class BackendNestedImpl<N> extends IngressBackendFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathFluent.BackendNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathFluent.BackendNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final IngressBackendBuilder builder;

            BackendNestedImpl(IngressBackend item) {
                this.builder = new IngressBackendBuilder(this, item);
                        
            }

            BackendNestedImpl() {
                this.builder = new IngressBackendBuilder(this);
                        
            }

            public N and() {
                return (N) HTTPIngressPathFluentImpl.this.withBackend(builder.build());
            }

            public N endBackend() {
                return and();
            }
    }


}
